Fallbacks

Struct Fallbacks 

pub struct Fallbacks { /* private fields */ }
The Fallback behavior is used to try different strategies until one succeeds.

It implements 3 modes, which differ in how they handle a childs return value:

The variants are gated behind features fallback,async_fallback and reactive_fallback respectively.

Examples:

The synchronous variant is gated behind feature fallback.

<Fallback>
   <Behavior1/>
   <Behavior2/>
   <Behavior3/>
</Fallback>

The asynchronous variant is gated behind feature async_fallback.

<AsyncFallback>
   <Behavior1/>
   <Behavior2/>
   <Behavior3/>
</AsyncFallback>

Implementations

Source

impl Fallbacks

pub const fn new(kind: FallbackKind) -> Self

Returns a Fallback behavior with the given kind.

pub fn create_fn(kind: FallbackKind) -> Box<BehaviorCreationFn>

Creates a creation_fn() for Fallback with the given kind.

pub fn register_with( registry: &mut impl BehaviorRegistry, name: &str, kind: FallbackKind, ) -> Result<(), Error>

Registers the Fallback behavior in the factory.

Errors
  • if registration fails