BehaviorTreeElement

Struct BehaviorTreeElement 

pub struct BehaviorTreeElement { /* private fields */ }
A tree elements.

Implementations

Source

impl BehaviorTreeElement

pub fn create( kind: TreeElementKind, behavior: BehaviorPtr, data: BehaviorData, ) -> Self

Construct a BehaviorTreeElement.

pub fn new( kind: TreeElementKind, behavior: BehaviorPtr, data: BehaviorData, children: BehaviorTreeElementList, conditions: Conditions, ) -> Self

Construct a BehaviorTreeElement.

pub const fn uid(&self) -> u16

Get the uid.

pub const fn id(&self) -> &Arc<str>

Get the id.

pub const fn name(&self) -> &Arc<str>

Returns the name of the behavior.

pub const fn data(&self) -> &BehaviorData

Returns a reference to the BehaviorData.

pub const fn data_mut(&mut self) -> &mut BehaviorData

Returns a mutable reference to the BehaviorData.

pub const fn behavior(&self) -> &BehaviorPtr

Returns a reference to the behavior.

pub const fn behavior_mut(&mut self) -> &mut BehaviorPtr

Returns a mutable reference to the behavior.

pub const fn blackboard(&self) -> &Databoard

Returns a reference to the blackboard.

pub const fn blackboard_mut(&mut self) -> &mut Databoard

Returns a reference to the blackboard.

pub const fn children(&self) -> &BehaviorTreeElementList

Returns the children.

pub const fn children_mut(&mut self) -> &mut BehaviorTreeElementList

Returns the children mutable.

pub const fn pre_conditions(&self) -> &PreConditions

Returns the pre conditions.

pub const fn pre_conditions_mut(&mut self) -> &mut PreConditions

Returns the pre condition mutables.

pub const fn post_conditions(&self) -> &PostConditions

Returns the post conditions.

pub const fn post_conditions_mut(&mut self) -> &mut PostConditions

Returns the post conditions mutable.

pub fn halt(&mut self, runtime: &SharedRuntime) -> Result<(), Error>

Halts the element and all its children considering postconditions.

Errors
pub async fn tick(&mut self, runtime: &SharedRuntime) -> BehaviorResult

Ticks the element considering pre- and postconditions.

Errors
pub fn halt_child_at( &mut self, index: usize, runtime: &SharedRuntime, ) -> Result<(), Error>

Halts child at index.

Errors
  • if index is out of childrens bounds.
pub fn halt_children_from( &mut self, index: usize, runtime: &SharedRuntime, ) -> Result<(), Error>

Halt all children at and beyond index.

Errors
  • if index is out of childrens bounds.
pub fn halt_children(&mut self, runtime: &SharedRuntime) -> Result<(), Error>

Halt all children at and beyond index.

Errors
  • if index is out of childrens bounds.
pub fn reset_state(&mut self)

Reset state of element.

pub fn add_pre_state_change_callback<T>(&mut self, name: Arc<str>, callback: T)
where T: Fn(&BehaviorData, &mut BehaviorState) + Send + Sync + 'static,

Add a pre state change callback with the given name. The name is not unique, which is important when removing callback.

pub fn remove_pre_state_change_callback(&mut self, name: &str)

Remove any pre state change callback with the given name.

pub fn children_iter(&self) -> impl DoubleEndedIterator<Item = &Self>

Return an iterator over the children.

pub fn children_iter_mut( &mut self, ) -> impl DoubleEndedIterator<Item = &mut Self>

Return a mutable iterator over the children.

pub fn iter(&self) -> impl Iterator<Item = &Self>

Get an iterator over the tree element.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Self>

Get a mutable iterator over the tree element.

pub const fn kind(&self) -> TreeElementKind

pub const fn groot2_path(&self) -> &Arc<str>

Returns the Groot2 style ‘path’ of the element.

pub const fn state(&self) -> BehaviorState

Returns the current state of the element.

pub fn add_child(&mut self, child: Self)

Adds a child to the elements children list.