pub struct Fallbacks { /* private fields */ }Expand description
The Fallback behavior is used to try different strategies until one succeeds.
It implements 3 modes, which differ in how they handle a childs return value:
- The synchronous mode will try to succeed within one tick from its parent.
If any child returns
BehaviorState::Running, previous children will NOT be ticked again.- If a child returns
BehaviorState::Failure, continue to the next sibling. If all the children fail, than this node returnsBehaviorState::Failure. - If a child returns
BehaviorState::Running, this node returnsBehaviorState::Runningand continues with the same child at the next tick from parent. - If a child returns
BehaviorState::Successthis behavior returnsBehaviorState::Success.
- If a child returns
- The asynchronous mode will return the flow contol after a childs failure to its parent.
If any child returns
BehaviorState::Running, previous children will NOT be ticked again.- If a the children returns
BehaviorState::Failure, this node returnsBehaviorState::Running. and continues with the next child at the next tick from parent. If all the children fail, than this node returnsBehaviorState::Failure. - If a child returns
BehaviorState::Running, this node returnsBehaviorState::Runningand continues with the same child at the next tick from parent. - If a child returns
BehaviorState::Successthis behavior returnsBehaviorState::Success.
- If a the children returns
- The reactive mode always ticks all children from first to last:
If any child returns
BehaviorState::Running, previous children will be ticked again. IMPORTANT: Having asynchronous children (aka children that returnBehaviorState::Running) makes this behavior difficult to predict. Avoid having more than one asynchronous children!- If a child returns
BehaviorState::Running, continue to the next sibling. - If a child returns
BehaviorState::Failure, continue to the next sibling. If all the children fail, than this node returnsBehaviorState::Failure. - If a child returns
BehaviorState::Success, stop running child and returnBehaviorState::Success.
- If a child returns
The variants are gated behind features fallback,async_fallback and reactive_fallback respectively.
Examples:
The synchronous variant is gated behind feature fallback.
<Fallback>
<Behavior1/>
<Behavior2/>
<Behavior3/>
</Fallback>The asynchronous variant is gated behind feature async_fallback.
<AsyncFallback>
<Behavior1/>
<Behavior2/>
<Behavior3/>
</AsyncFallback>Implementations
Sourceimpl Fallbacks
impl Fallbacks
Sourcepub const fn new(kind: FallbackKind) -> Self
pub const fn new(kind: FallbackKind) -> Self
Returns a Fallback behavior with the given kind.
Sourcepub fn create_fn(kind: FallbackKind) -> Box<BehaviorCreationFn>
pub fn create_fn(kind: FallbackKind) -> Box<BehaviorCreationFn>
Creates a creation_fn() for Fallback with the given kind.
Sourcepub fn register_with(
registry: &mut impl BehaviorRegistry,
name: &str,
kind: FallbackKind,
) -> Result<(), Error>
pub fn register_with( registry: &mut impl BehaviorRegistry, name: &str, kind: FallbackKind, ) -> Result<(), Error>