pub struct Parallel { /* private fields */ }Expand description
A Parallel behaviors executes its children concurrently in one thread.
It differs from ParallelAll in how it handles the parallelity:
The standard variant is completed either when the success_threshold or the failure_threshold is reached.
These are configured using the ports success_count and failure_count.
If any of the thresholds is reached, still running children will be halted.
Both ports default to -1 which means any number or don’t care.
The variant is gated behind the feature parallel.
Example:
<Parallel success_count="2" failure_count="1">
<Behavior1/>
<Behavior2/>
<Behavior3/>
</Parallel>Implementations